==> xwiki-platform-extension-api-3.3-rc-1-sources.jar: org/xwiki/extension/ExtensionManagerConfiguration.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension;

import java.io.File;
import java.util.List;

import org.xwiki.component.annotation.ComponentRole;
import org.xwiki.extension.repository.ExtensionRepositoryId;

/**
 * Provide some general extension manager configuration.
 * 
 * @version $Id$
 */
@ComponentRole
public interface ExtensionManagerConfiguration
{
    /**
     * @return the folder containing the local extensions
     * @see org.xwiki.extension.repository.LocalExtensionRepository
     */
    File getLocalRepository();

    /**
     * @return the configured repositories
     */
    List<ExtensionRepositoryId> getRepositories();
}

==> xwiki-platform-extension-api-3.5.1-sources.jar: org/xwiki/extension/ExtensionManagerConfiguration.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension;

import java.io.File;
import java.util.List;

import org.xwiki.component.annotation.ComponentRole;
import org.xwiki.extension.repository.ExtensionRepositoryId;

/**
 * Provide some general extension manager configuration.
 * 
 * @version $Id$
 */
@ComponentRole
public interface ExtensionManagerConfiguration
{
    /**
     * @return the folder containing the local extensions
     * @see org.xwiki.extension.repository.LocalExtensionRepository
     */
    File getLocalRepository();

    /**
     * @return the configured repositories
     */
    List<ExtensionRepositoryId> getRepositories();

    /**
     * @return the user agent to declare when communication with external services (generally repositories)
     */
    String getUserAgent();
}
